@@ -7,7 +7,7 @@
 #include "col.h"
 #include "utils.h"
 
-#define CONF_VER 23
+#define CONF_VER 24
 #define CONFIG_KEY "config"
 
 #define LIM(v, min, max) {if (v >= max) v = max; else if (v <= min) v = min;}
@@ -110,7 +110,7 @@ config_init(void)
    EET_DATA_DESCRIPTOR_ADD_BASIC
      (edd_base, Config, "tab_zoom", tab_zoom, EET_T_DOUBLE);
    EET_DATA_DESCRIPTOR_ADD_BASIC
-     (edd_base, Config, "vidmod", vidmod, EET_T_INT);
+     (edd_base, Config, "vidmod", _vidmod, EET_T_INT); /* DEPRECATED */
    EET_DATA_DESCRIPTOR_ADD_BASIC
      (edd_base, Config, "jump_on_change", jump_on_change, EET_T_UCHAR);
    EET_DATA_DESCRIPTOR_ADD_BASIC
@@ -191,6 +191,8 @@ config_init(void)
      (edd_base, Config, "shine", shine, EET_T_INT);
    EET_DATA_DESCRIPTOR_ADD_BASIC
      (edd_base, Config, "hide_cursor", hide_cursor, EET_T_DOUBLE);
+   EET_DATA_DESCRIPTOR_ADD_BASIC
+     (edd_base, Config, "group_all", group_all, EET_T_UCHAR);
 }
 
 void
@@ -283,7 +285,6 @@ config_sync(const Config *config_src, Config *config)
    config->scrollback = config_src->scrollback;
    config->tab_zoom = config_src->tab_zoom;
    config->hide_cursor = config_src->hide_cursor;
-   config->vidmod = config_src->vidmod;
    config->jump_on_keypress = config_src->jump_on_keypress;
    config->jump_on_change = config_src->jump_on_change;
    config->flicker_on_key = config_src->flicker_on_key;
@@ -318,6 +319,9 @@ config_sync(const Config *config_src, Config *config)
    config->changedir_to_current = config_src->changedir_to_current;
    config->emoji_dbl_width = config_src->emoji_dbl_width;
    config->shine = config_src->shine;
+   config->translucent = config_src->translucent;
+   config->opacity = config_src->opacity;
+   config->group_all = config_src->group_all;
 }
 
 static void
@@ -545,7 +549,6 @@ config_new(void)
         config->theme = eina_stringshare_add("default.edj");
         config->background = NULL;
         config->tab_zoom = 0.5;
-        config->vidmod = 0;
         config->opacity = 50;
         config->cg_width = 80;
         config->cg_height = 24;
@@ -595,6 +598,7 @@ config_new(void)
         _add_default_keys(config);
         config->shine = 255;
         config->hide_cursor = 5.0;
+        config->group_all = EINA_FALSE;
      }
    return config;
 }
@@ -631,7 +635,7 @@ config_load(void)
                   LIM(config->font.size, 3, 400);
                   LIM(config->scrollback, 0, 131072);
                   LIM(config->tab_zoom, 0.0, 1.0);
-                  LIM(config->vidmod, 0, 4)
+                  LIM(config->_vidmod, 0, 4)
 
                   /* upgrade to v3 */
                   config->active_links = EINA_TRUE;
@@ -728,8 +732,11 @@ config_load(void)
                 case 22:
                   config->show_tabs = !config->notabs;
                   EINA_FALLTHROUGH;
+                case 23:
+                  config->group_all = EINA_FALSE;
+                  EINA_FALLTHROUGH;
                   /*pass through*/
-                case CONF_VER: /* 23 */
+                case CONF_VER: /* 24 */
                   config->version = CONF_VER;
                   break;
                 default:
@@ -796,7 +803,6 @@ config_fork(const Config *config)
    CPY(scrollback);
    CPY(tab_zoom);
    CPY(hide_cursor);
-   CPY(vidmod);
    CPY(jump_on_change);
    CPY(jump_on_keypress);
    CPY(flicker_on_key);
@@ -833,6 +839,7 @@ config_fork(const Config *config)
    CPY(changedir_to_current);
    CPY(emoji_dbl_width);
    CPY(shine);
+   CPY(group_all);
 
    EINA_LIST_FOREACH(config->keys, l, key)
      {
