@@ -413,7 +413,7 @@ main_ipc_new(Ipc_Instance *inst)
    if (win_term_set(wn, term) < 0)
      return;
 
-   main_trans_update(config);
+   main_trans_update();
    main_media_update(config);
    if (inst->pos)
      {
@@ -434,11 +434,6 @@ main_ipc_new(Ipc_Instance *inst)
    unsetenv("DESKTOP_STARTUP_ID");
 }
 
-static const char *emotion_choices[] = {
-  "auto", "gstreamer", "xine", "generic", "gstreamer1",
-  NULL
-};
-
 static Ecore_Getopt options = {
    PACKAGE_NAME,
    "%prog [options]",
@@ -473,9 +468,6 @@ static Ecore_Getopt options = {
                               " 'v' for vertical and 'h' for horizontal."
                               " Can be used multiple times. eg -S vhvv or --split hv"
                               " More description available on the man page.")),
-      ECORE_GETOPT_CHOICE    ('v', "video-module",
-                              gettext_noop("Set emotion module to use."), emotion_choices),
-
       ECORE_GETOPT_STORE_BOOL('l', "login",
                               gettext_noop("Run the shell as a login shell.")),
       ECORE_GETOPT_STORE_BOOL('m', "video-mute",
@@ -502,8 +494,12 @@ static Ecore_Getopt options = {
                               gettext_noop("Force single executable if multi-instance is enabled.")),
       ECORE_GETOPT_STORE_TRUE('2', "256color",
                               gettext_noop("Set TERM to 'xterm-256color' instead of 'xterm'.")),
+      ECORE_GETOPT_STORE_DOUBLE('\0', "scale",
+                              gettext_noop("Set scaling factor.")),
       ECORE_GETOPT_STORE_BOOL('\0', "active-links",
                               gettext_noop("Highlight links.")),
+      ECORE_GETOPT_STORE_BOOL('\0', "no-wizard",
+                              gettext_noop("Do not display wizard on start up.")),
 
       ECORE_GETOPT_VERSION   ('V', "version"),
       ECORE_GETOPT_COPYRIGHT ('C', "copyright"),
@@ -518,7 +514,7 @@ static void
 _translate_options(void)
 {
    options.copyright = eina_stringshare_printf(gettext(options.copyright),
-                                               2019);
+                                               2020);
 
    Ecore_Getopt_Desc *desc = (Ecore_Getopt_Desc *) options.descs;
    while ((desc->shortname != '\0') || (desc->longname) ||
@@ -564,7 +560,7 @@ _log_void(const Eina_Log_Domain *_d EINA_UNUSED,
 #endif
 
 static void
-_start(Ipc_Instance *instance)
+_start(Ipc_Instance *instance, Eina_Bool need_scale_wizard)
 {
    Win *wn;
    Evas_Object *win;
@@ -603,7 +599,7 @@ _start(Ipc_Instance *instance)
         goto exit;
      }
 
-   main_trans_update(config);
+   main_trans_update();
    main_media_update(config);
    win_sizing_handle(wn);
    win = win_evas_object_get(wn);
@@ -611,7 +607,6 @@ _start(Ipc_Instance *instance)
    if (instance->startup_split)
      {
         unsigned int i = 0;
-        Eina_List *cmds_list = NULL;
         Term *next = term;
 
         for (i = 0; i < strlen(instance->startup_split); i++)
@@ -620,17 +615,17 @@ _start(Ipc_Instance *instance)
 
              if (instance->startup_split[i] == 'v')
                {
-                  cmd = cmds_list ? cmds_list->data : NULL;
-                  split_vertically(win_evas_object_get(term_win_get(next)),
-                                   term_termio_get(next), cmd);
-                  cmds_list = eina_list_remove_list(cmds_list, cmds_list);
+                  cmd = eina_list_data_get(instance->cmds);
+                  split_vertically(term_termio_get(next), cmd);
+                  instance->cmds = eina_list_remove_list(instance->cmds,
+                                                         instance->cmds);
                }
              else if (instance->startup_split[i] == 'h')
                {
-                  cmd = cmds_list ? cmds_list->data : NULL;
-                  split_horizontally(win_evas_object_get(term_win_get(next)),
-                                     term_termio_get(next), cmd);
-                  cmds_list = eina_list_remove_list(cmds_list, cmds_list);
+                  cmd = eina_list_data_get(instance->cmds);
+                  split_horizontally(term_termio_get(next), cmd);
+                  instance->cmds = eina_list_remove_list(instance->cmds,
+                                                         instance->cmds);
                }
              else if (instance->startup_split[i] == '-')
                next = term_next_get(next);
@@ -641,8 +636,6 @@ _start(Ipc_Instance *instance)
                   goto end;
                }
           }
-        if (cmds_list)
-          eina_list_free(cmds_list);
      }
    if (instance->pos)
      {
@@ -659,7 +652,8 @@ _start(Ipc_Instance *instance)
 
    controls_init();
 
-   win_scale_wizard(win, term);
+   if (need_scale_wizard)
+     win_scale_wizard(win, term);
 
    terminology_starting_up = EINA_FALSE;
 
@@ -757,7 +751,8 @@ _instance_add_waiter(Ipc_Instance *instance,
 
 static Eina_Bool
 _start_multi(Ipc_Instance *instance,
-             char **argv)
+             char **argv,
+             Eina_Bool need_scale_wizard)
 {
    int remote_try = 0;
    do
@@ -782,7 +777,7 @@ _start_multi(Ipc_Instance *instance,
    while (remote_try <= 1);
 
 normal_start:
-   _start(instance);
+   _start(instance, need_scale_wizard);
    return EINA_FALSE;
 
 exit:
@@ -793,10 +788,11 @@ EAPI_MAIN int
 elm_main(int argc, char **argv)
 {
    char *geometry = NULL;
-   char *video_module = NULL;
    Eina_Bool quit_option = EINA_FALSE;
    Eina_Bool single = EINA_FALSE;
+   Eina_Bool no_wizard = EINA_FALSE;
    Eina_Bool cmd_options = EINA_FALSE;
+   double scale = -1.0; /* unset */
    Ipc_Instance instance = {
         .login_shell = 0xff, /* unset */
         .active_links = 0xff, /* unset */
@@ -819,7 +815,6 @@ elm_main(int argc, char **argv)
      ECORE_GETOPT_VALUE_STR(instance.icon_name),
      ECORE_GETOPT_VALUE_STR(instance.font),
      ECORE_GETOPT_VALUE_STR(instance.startup_split),
-     ECORE_GETOPT_VALUE_STR(video_module),
 
      ECORE_GETOPT_VALUE_BOOL(instance.login_shell),
      ECORE_GETOPT_VALUE_BOOL(instance.video_mute),
@@ -834,7 +829,9 @@ elm_main(int argc, char **argv)
      ECORE_GETOPT_VALUE_BOOL(instance.hold),
      ECORE_GETOPT_VALUE_BOOL(single),
      ECORE_GETOPT_VALUE_BOOL(instance.xterm_256color),
+     ECORE_GETOPT_VALUE_DOUBLE(scale),
      ECORE_GETOPT_VALUE_BOOL(instance.active_links),
+     ECORE_GETOPT_VALUE_BOOL(no_wizard),
 
      ECORE_GETOPT_VALUE_BOOL(quit_option),
      ECORE_GETOPT_VALUE_BOOL(quit_option),
@@ -845,6 +842,7 @@ elm_main(int argc, char **argv)
    };
    int args, retval = EXIT_SUCCESS;
    Eina_Bool size_set = EINA_FALSE;
+   Eina_Bool need_scale_wizard = utils_need_scale_wizard();
 
    terminology_starting_up = EINA_TRUE;
 
@@ -869,7 +867,7 @@ elm_main(int argc, char **argv)
    textdomain(PACKAGE);
    _translate_options();
 #else
-   options.copyright = "(C) 2012-2019 Carsten Haitzler and others";
+   options.copyright = "(C) 2012-2020 Carsten Haitzler and others";
 #endif
 
    _log_domain = eina_log_domain_register("terminology", NULL);
@@ -905,11 +903,21 @@ elm_main(int argc, char **argv)
         goto end;
      }
 
-   if (quit_option) goto end;
+   if (scale > 0.0)
+     {
+        elm_config_scale_set(scale);
+        elm_config_all_flush();
+        instance.config->temporary = EINA_TRUE;
+     }
+
+   if (no_wizard)
+     need_scale_wizard = EINA_FALSE;
+
+   if (quit_option)
+     goto end;
 
    if (cmd_options)
      {
-        Eina_List *cmds_list = NULL;
         int i;
 
         if (args == argc)
@@ -922,7 +930,7 @@ elm_main(int argc, char **argv)
         if (instance.startup_split)
           {
              for(i = args+1; i < argc; i++)
-               cmds_list = eina_list_append(cmds_list, argv[i]);
+               instance.cmds = eina_list_append(instance.cmds, argv[i]);
              instance.cmd = argv[args];
           }
         else
@@ -945,22 +953,6 @@ elm_main(int argc, char **argv)
    _configure_instance(&instance);
 
 
-   if (video_module)
-     {
-        int i;
-        for (i = 0; i < (int)EINA_C_ARRAY_LENGTH(emotion_choices); i++)
-          {
-             if (video_module == emotion_choices[i])
-               break;
-          }
-
-        if (i == EINA_C_ARRAY_LENGTH(emotion_choices))
-          i = 0; /* ecore getopt shouldn't let this happen, but... */
-        instance.config->vidmod = i;
-        instance.config->temporary = EINA_TRUE;
-     }
-
-
    if (geometry)
      {
         if (sscanf(geometry,"%ix%i+%i+%i", &instance.w, &instance.h,
@@ -1041,12 +1033,12 @@ elm_main(int argc, char **argv)
 
         if (!instance.cd)
           instance.cd = getcwd(cwdbuf, sizeof(cwdbuf));
-        if (_start_multi(&instance, argv))
+        if (_start_multi(&instance, argv, need_scale_wizard))
           goto end;
      }
    else
      {
-        _start(&instance);
+        _start(&instance, need_scale_wizard);
      }
    elm_run();
 
