@@ -54,14 +54,17 @@ static Evas_Smart_Class _parent_sc = EVAS_SMART_CLASS_INIT_NULL;
 static const char *
 _is_fmt(const char *f, const char **extn)
 {
-   int i, len, l;
+   int i;
+   size_t len;
 
    len = strlen(f);
    for (i = 0; extn[i]; i++)
      {
-        l = strlen(extn[i]);
-        if (len < l) continue;
-        if (!strcasecmp(extn[i], f + len - l)) return extn[i];
+        size_t l = strlen(extn[i]);
+        if (len < l)
+          continue;
+        if (!strcasecmp(extn[i], f + len - l))
+          return extn[i];
      }
    return NULL;
 }
@@ -472,7 +475,6 @@ _type_scale_init(Evas_Object *obj)
 static void
 _type_scale_calc(Evas_Object *obj, Evas_Coord x, Evas_Coord y, Evas_Coord w, Evas_Coord h)
 {
-   Evas_Object *o;
    Media *sd = evas_object_smart_data_get(obj);
    if (!sd) return;
    if ((w <= 0) || (h <= 0) || (sd->iw <= 0) || (sd->ih <= 0))
@@ -526,6 +528,8 @@ _type_scale_calc(Evas_Object *obj, Evas_Coord x, Evas_Coord y, Evas_Coord w, Eva
         if (lh < 256) lh = 256;
         if ((lw != sd->sw) || (lh != sd->sh))
           {
+             Evas_Object *o;
+
              o = sd->o_tmp = evas_object_image_filled_add(evas_object_evas_get(obj));
              evas_object_smart_member_add(o, obj);
              evas_object_clip_set(o, sd->clip);
@@ -785,31 +789,12 @@ _type_mov_init(Evas_Object *obj)
 {
    Evas_Object *o;
    double vol;
-   char *modules[] =
-     {
-        NULL,
-        "gstreamer",
-        "xine",
-        "vlc",
-        "gstreamer1"
-    };
-   char *mod = NULL;
    Media *sd = evas_object_smart_data_get(obj);
 
    EINA_SAFETY_ON_NULL_RETURN_VAL(sd, -1);
 
    emotion_init();
    o = sd->o_img = emotion_object_add(evas_object_evas_get(obj));
-   if ((sd->config->vidmod >= 0) &&
-       (sd->config->vidmod < (int)EINA_C_ARRAY_LENGTH(modules)))
-     mod = modules[sd->config->vidmod];
-   if (!emotion_object_init(o, mod))
-     {
-        ERR(_("Could not Initialize the emotion module '%s'"), mod);
-        evas_object_del(sd->o_img);
-        sd->o_img = NULL;
-        return -1;
-     }
    evas_object_smart_callback_add(o, "frame_decode",
                                   _cb_mov_frame_decode, obj);
    evas_object_smart_callback_add(o, "frame_resize",
@@ -964,8 +949,8 @@ _smart_del(Evas_Object *obj)
         if (sd->realf) unlink(sd->realf);
         close(sd->tmpfd);
      }
-   if (sd->src) eina_stringshare_del(sd->src);
-   if (sd->realf) eina_stringshare_del(sd->realf);
+   eina_stringshare_del(sd->src);
+   eina_stringshare_del(sd->realf);
    if (sd->clip) evas_object_del(sd->clip);
    if (sd->o_img) evas_object_del(sd->o_img);
    if (sd->o_tmp) evas_object_del(sd->o_tmp);
