@@ -7,7 +7,6 @@
 #include "options_theme.h"
 #include "options_background.h"
 #include "options_colors.h"
-#include "options_video.h"
 #include "options_behavior.h"
 #include "options_keys.h"
 #include "options_helpers.h"
@@ -23,7 +22,6 @@ enum option_mode {
      OPTION_THEME,
      OPTION_BACKGROUND,
      OPTION_COLORS,
-     OPTION_VIDEO,
      OPTION_KEYS,
      OPTION_HELPERS,
      OPTION_ELM,
@@ -90,7 +88,6 @@ _cb_opdt_hide_done(void *data,
       case OPTION_THEME:     options_theme(ctx->opbox, ctx->term); break;
       case OPTION_BACKGROUND: options_background(ctx->opbox, ctx->term); break;
       case OPTION_COLORS:    options_colors(ctx->opbox, ctx->term, ctx->bg); break;
-      case OPTION_VIDEO:     options_video(ctx->opbox, ctx->term); break;
       case OPTION_KEYS:      options_keys(ctx->opbox, ctx->term); break;
       case OPTION_HELPERS:   options_helpers(ctx->opbox, ctx->term); break;
       case OPTION_ELM:       options_elm(ctx->opbox, ctx->term); break;
@@ -207,11 +204,11 @@ options_show(Evas_Object *win, Evas_Object *base, Evas_Object *bg, Evas_Object *
    evas_object_size_hint_align_set(o, 0.5, EVAS_HINT_FILL);
    elm_toolbar_horizontal_set(o, EINA_FALSE);
    elm_object_style_set(o, "item_horizontal");
-   elm_toolbar_icon_size_set(o, 16 * elm_config_scale_get());
+   elm_toolbar_icon_size_set(o, 24 * elm_config_scale_get());
    elm_toolbar_shrink_mode_set(o, ELM_TOOLBAR_SHRINK_SCROLL);
    elm_toolbar_select_mode_set(o, ELM_OBJECT_SELECT_MODE_ALWAYS);
    elm_toolbar_menu_parent_set(o, win);
-   elm_toolbar_homogeneous_set(o, EINA_FALSE);
+   elm_toolbar_homogeneous_set(o, EINA_TRUE);
 
 #define ITEM_APPEND(_icon_name, _name, _option_mode) \
    elm_toolbar_item_append(o, _icon_name, _name, _cb_op, \
@@ -220,12 +217,11 @@ options_show(Evas_Object *win, Evas_Object *base, Evas_Object *bg, Evas_Object *
    it_fn = ITEM_APPEND("preferences-system", _("Behavior"), BEHAVIOR);
    ITEM_APPEND("preferences-desktop-font", _("Font"), FONT);
    ITEM_APPEND("preferences-desktop-theme", _("Theme"), THEME);
-   ITEM_APPEND("preferences-desktop-background", _("Background"), BACKGROUND);
-   ITEM_APPEND("preferences-desktop-theme", _("Colors"), COLORS);
-   ITEM_APPEND("video-display", _("Video"), VIDEO);
-   ITEM_APPEND("preferences-desktop-keyboard-shortcuts", _("Keys"), KEYS);
+   ITEM_APPEND("preferences-desktop-wallpaper", _("Background"), BACKGROUND);
+   ITEM_APPEND("preferences-color", _("Colors"), COLORS);
+   ITEM_APPEND("preferences-desktop-keyboard", _("Keys"), KEYS);
    ITEM_APPEND("system-run", _("Helpers"), HELPERS);
-   ITEM_APPEND("preferences-color", _("Toolkit"), ELM);
+   ITEM_APPEND("preferences-desktop", _("Toolkit"), ELM);
 #undef ITEM_APPEND
 
    elm_box_pack_end(op_tbox, o);
