@@ -4,6 +4,8 @@
 #include <math.h>
 #include <Elementary.h>
 #include <assert.h>
+#include "termpty.h"
+#include "backlog.h"
 #include "config.h"
 #include "termio.h"
 #include "options.h"
@@ -17,6 +19,8 @@ typedef struct _Behavior_Ctx {
      Evas_Object *op_wh_current;
      Evas_Object *term;
      Evas_Object *sld_hide_cursor;
+     Evas_Object *backlock_label;
+     char *backlog_msg;
      Config *config;
 } Behavior_Ctx;
 
@@ -61,6 +65,7 @@ CB(mv_always_show, 0);
 CB(ty_escapes, 0);
 CB(changedir_to_current, 0);
 CB(emoji_dbl_width, 0);
+CB(group_all, 0);
 
 #undef CB
 
@@ -85,6 +90,24 @@ sback_units_format(double d)
     return (char*)eina_stringshare_printf(_("%'d lines"), sback_double_to_expo_int(d));
 }
 
+static void
+_update_backlog_title(Behavior_Ctx *ctx)
+{
+   char *factor = " KMG";
+   double amount = termpty_backlog_memory_get();
+
+   while (amount > 1024.0 && factor[1] != '\0')
+     {
+        amount /= 1024;
+        factor++;
+     }
+   eina_stringshare_del(ctx->backlog_msg);
+   ctx->backlog_msg = (char*) eina_stringshare_printf(
+      _("Scrollback (current memory usage: %'.2f%cB):"),
+      amount, factor[0]);
+   elm_object_text_set(ctx->backlock_label, ctx->backlog_msg);
+}
+
 static void
 _cb_op_behavior_sback_chg(void *data,
                           Evas_Object *obj,
@@ -95,6 +118,7 @@ _cb_op_behavior_sback_chg(void *data,
 
    config->scrollback = (double) sback_double_to_expo_int(elm_slider_value_get(obj));
    termio_config_update(ctx->term);
+   _update_backlog_title(ctx);
    config_save(config);
 }
 
@@ -187,6 +211,7 @@ _parent_del_cb(void *data,
 {
    Behavior_Ctx *ctx = data;
 
+   eina_stringshare_del(ctx->backlog_msg);
    free(ctx);
 }
 
@@ -488,6 +513,7 @@ options_behavior(Evas_Object *opbox, Evas_Object *term)
    CX(_("Enable special Terminology escape codes"), ty_escapes, 0);
    CX(_("Open new terminals in current working directory"), changedir_to_current, 0);
    CX(_("Treat Emojis as double-width characters"), emoji_dbl_width, 0);
+   CX(_("When grouping input, do it on all terminals and not just the visible ones"), group_all, 0);
 
 #undef CX
 
@@ -563,7 +589,8 @@ options_behavior(Evas_Object *opbox, Evas_Object *term)
    o = elm_label_add(bx);
    evas_object_size_hint_weight_set(o, 0.0, 0.0);
    evas_object_size_hint_align_set(o, 0.0, 0.5);
-   elm_object_text_set(o, _("Scrollback:"));
+   ctx->backlock_label = o;
+   _update_backlog_title(ctx);
    elm_box_pack_end(bx, o);
    evas_object_show(o);
 
