@@ -57,15 +57,27 @@ _termcmd_font_size(Evas_Object *obj,
                   eina_stringshare_del(config->font.name);
                   config->font.name = eina_stringshare_add("10x20.pcf");
                }
-             new_size = 20;
+             new_size = config->font.size * 2;
           }
         else if (cmd[0] == '+') // size up
           {
-             new_size = config->font.size + 1;
+             int i;
+
+             new_size = config->font.size;
+             for (i = 0; cmd[i] == '+'; i++)
+               {
+                  new_size = ((double)new_size * 1.4) + 1;
+               }
           }
         else if (cmd[0] == '-') // size down
           {
-             new_size = config->font.size - 1;
+             int i;
+
+             new_size = config->font.size;
+             for (i = 0; cmd[i] == '-'; i++)
+               {
+                  new_size = (double)(new_size - 1) / 1.4;
+               }
           }
         else
           {
