@@ -5,6 +5,7 @@
 #include "termio.h"
 #include "miniview.h"
 #include "termpty.h"
+#include "backlog.h"
 #include "termptydbl.h"
 #include "termptyops.h"
 #include "termiointernals.h"
@@ -414,9 +415,21 @@ termio_internal_get_selection(Termio *sd, size_t *lenp)
 
              if (isb.len)
                {
+                  int res;
                   if (isb.buf[isb.len - 1] != '\n' && i != end_y)
-                    ty_sb_add(&isb, "\n", 1);
-                  ty_sb_add(&sb, isb.buf, isb.len);
+                    {
+                       res = ty_sb_add(&isb, "\n", 1);
+                       if (res < 0)
+                         {
+                            ERR("failure to add newline to selection buffer");
+                         }
+                    }
+                  res = ty_sb_add(&sb, isb.buf, isb.len);
+                  if (res < 0)
+                    {
+                       ERR("failure to add %zd characters to selection buffer",
+                           isb.len);
+                    }
                }
              ty_sb_free(&isb);
           }
@@ -1996,7 +2009,11 @@ _mouse_selection_scroll(void *data)
    if (!sd->pty->selection.makesel)
      return EINA_FALSE;
 
+#if defined(ENABLE_TESTS) || defined(ENABLE_TEST_UI)
+   test_pointer_canvas_xy_get(NULL, &my);
+#else
    evas_pointer_canvas_xy_get(evas_object_evas_get(sd->self), NULL, &my);
+#endif
    termio_object_geometry_get(sd, NULL, &oy, NULL, NULL);
    fcy = (my - oy) / (float)sd->font.chh;
    cy = fcy;
@@ -2074,11 +2091,15 @@ termio_internal_mouse_move(Termio *sd,
      }
    if (scroll == EINA_TRUE)
      {
+#if defined(ENABLE_TESTS) || defined(ENABLE_TEST_UI)
+        _mouse_selection_scroll(sd);
+#else
         if (!sd->mouse_selection_scroll_timer)
           {
              sd->mouse_selection_scroll_timer
-                = ecore_timer_add(0.05, _mouse_selection_scroll, sd);
+                = ecore_timer_add(0.04 , _mouse_selection_scroll, sd);
           }
+#endif
         return;
      }
    else if (sd->mouse_selection_scroll_timer)
@@ -2122,7 +2143,9 @@ termio_internal_mouse_move(Termio *sd,
           {
              if ((cx != start_x) ||
                  ((cy - sd->scroll) != start_y))
-               termio_sel_set(sd, EINA_TRUE);
+               {
+                  termio_sel_set(sd, EINA_TRUE);
+               }
           }
 
         if (sd->pty->selection.by_line)
@@ -2393,7 +2416,6 @@ termio_internal_render(Termio *sd,
    const char *preedit_str;
    ssize_t w;
    int sel_start_x = 0, sel_start_y = 0, sel_end_x = 0, sel_end_y = 0;
-   Eina_Unicode *cp;
    Termblock *blk;
    Eina_List *l;
 
@@ -2417,15 +2439,16 @@ termio_internal_render(Termio *sd,
         INT_SWAP(sel_start_y, sel_end_y);
         INT_SWAP(sel_start_x, sel_end_x);
      }
-   cp = sd->pty->selection.codepoints;
 
    /* Look at every visible line */
    for (y = 0; y < sd->grid.h; y++)
      {
         Termcell *cells;
         Evas_Textgrid_Cell *tc;
+        Eina_Unicode *cp = NULL;
         int cur_sel_start_x = -1, cur_sel_end_x = -1;
         int rel_y = y - sd->scroll;
+        int l1 = -1, l2 = -1;
 
         w = 0;
         cells = termpty_cellrow_get(sd->pty, rel_y, &w);
@@ -2438,15 +2461,18 @@ termio_internal_render(Termio *sd,
         /* Compute @cur_sel_start_x, @cur_sel_end_x */
         if (sd->pty->selection.codepoints)
           {
+             cp = sd->pty->selection.codepoints;
              if (sel_start_y <= rel_y && rel_y <= sel_end_y)
                {
                   if (sd->pty->selection.is_box)
                     {
+                       cp += (rel_y - sel_start_y) * (sel_end_x - sel_start_x + 1);
                        cur_sel_start_x = sel_start_x;
                        cur_sel_end_x = sel_end_x;
                     }
                   else
                     {
+                       cp += (rel_y - sel_start_y) * sd->pty->w;
                        cur_sel_start_x = sel_start_x;
                        cur_sel_end_x = sel_end_x;
                        if (sel_start_y != sel_end_y)
@@ -2457,10 +2483,12 @@ termio_internal_render(Termio *sd,
                               }
                             else if (rel_y == sel_end_y)
                               {
+                                 cp -= sel_start_x;
                                  cur_sel_start_x = 0;
                               }
                             else
                               {
+                                 cp -= sel_start_x;
                                  cur_sel_start_x = 0;
                                  cur_sel_end_x = sd->grid.w - 1;
                               }
@@ -2468,6 +2496,35 @@ termio_internal_render(Termio *sd,
                     }
                }
           }
+        if (EINA_UNLIKELY(sd->link.objs != NULL))
+          {
+             if (sd->link.y1 == sd->link.y2)
+               {
+                  if (y == sd->link.y1)
+                    {
+                       l1 = sd->link.x1;
+                       l2 = sd->link.x2;
+                    }
+               }
+             else
+               {
+                  if (y == sd->link.y1)
+                    {
+                       l1 = sd->link.x1;
+                       l2 = w;
+                    }
+                  else if (y == sd->link.y2)
+                    {
+                       l1 = 0;
+                       l2 = sd->link.x2;
+                    }
+                  else if (y > sd->link.y1 && y < sd->link.y2)
+                    {
+                       l1 = sd->link.x1;
+                       l2 = sd->link.x2;
+                    }
+               }
+          }
 
         ch1 = -1;
         /* Look at every cell in that line */
@@ -2502,6 +2559,11 @@ termio_internal_render(Termio *sd,
                        termio_sel_set(sd, EINA_FALSE);
                        u = cp = NULL;
                     }
+                  if (EINA_UNLIKELY(l1 >= 0 && x >= l1 && x <= l2))
+                    {
+                       termio_remove_links(sd);
+                       l1 = l2 = -1;
+                    }
                }
              else
                {
@@ -2541,6 +2603,11 @@ termio_internal_render(Termio *sd,
                             termio_sel_set(sd, EINA_FALSE);
                             u = cp = NULL;
                          }
+                       if (EINA_UNLIKELY(l1 >= 0 && x >= l1 && x <= l2))
+                         {
+                            termio_remove_links(sd);
+                            l1 = l2 = -1;
+                         }
                     }
                   else if (cells[x].att.invisible)
                     {
@@ -2568,6 +2635,11 @@ termio_internal_render(Termio *sd,
                             termio_sel_set(sd, EINA_FALSE);
                             u = cp = NULL;
                          }
+                       if (EINA_UNLIKELY(l1 >= 0 && x >= l1 && x <= l2))
+                         {
+                            termio_remove_links(sd);
+                            l1 = l2 = -1;
+                         }
                     }
                   else
                     {
@@ -2645,6 +2717,12 @@ termio_internal_render(Termio *sd,
                        tc[x].double_width = cells[x].att.dblwidth;
                        tc[x].fg = fg;
                        tc[x].bg = bg;
+                       if (tc[x].codepoint != codepoint &&
+                           EINA_UNLIKELY(l1 >= 0 && x >= l1 && x <= l2))
+                         {
+                            termio_remove_links(sd);
+                            l1 = l2 = -1;
+                         }
                        tc[x].codepoint = codepoint;
                        if ((tc[x].double_width) && (tc[x].codepoint == 0) &&
                            (ch2 == x - 1))
@@ -2671,17 +2749,23 @@ termio_internal_render(Termio *sd,
    preedit_str = term_preedit_str_get(sd->term);
    if (preedit_str && preedit_str[0])
      {
-        Eina_Unicode *uni, g;
-        int len = 0, i, jump, xx, backx;
-        Eina_Bool dbl;
-        Evas_Textgrid_Cell *tc;
+        Eina_Unicode *uni;
+        int len = 0;
         x = sd->cursor.x, y = sd->cursor.y;
 
         uni = eina_unicode_utf8_to_unicode(preedit_str, &len);
         if (uni)
           {
+             int i;
              for (i = 0; i < len; i++)
                {
+                  int backx;
+                  int xx;
+                  int jump;
+                  Eina_Bool dbl;
+                  Evas_Textgrid_Cell *tc;
+                  Eina_Unicode g;
+
                   jump = 1;
                   g = uni[i];
                   dbl = _termpty_is_dblwidth_get(sd->pty, g);
