@@ -6,7 +6,7 @@
 #include "termpty.h"
 #include "termptyesc.h"
 #include "termptyops.h"
-#include "termptysave.h"
+#include "backlog.h"
 #include "keyin.h"
 #if !defined(ENABLE_FUZZING) && !defined(ENABLE_TESTS)
 # include "win.h"
@@ -225,39 +225,17 @@ _pty_size(Termpty *ty)
 }
 
 static Eina_Bool
-_fd_read_do(Termpty *ty, Ecore_Fd_Handler *fd_handler, Eina_Bool false_on_empty)
+_handle_read(Termpty *ty, Eina_Bool false_on_empty)
 {
-   char buf[4097];
-   Eina_Unicode codepoint[4097];
-   int len, i, j, reads;
-   unsigned int k;
-
-   if (ecore_main_fd_handler_active_get(fd_handler, ECORE_FD_ERROR))
-     {
-        DBG("error while reading from tty slave fd");
-        ty->hand_fd = NULL;
-        return ECORE_CALLBACK_CANCEL;
-     }
-   if (ty->fd == -1)
-     {
-        ty->hand_fd = NULL;
-        return ECORE_CALLBACK_CANCEL;
-     }
-
-/* it seems the BSDs can not read from this side of the pair if the other side
- * is closed */
-#if defined(__FreeBSD__) || defined(__DragonFly__) || defined(__OpenBSD__) || defined(__NetBSD__)
-   if (ty->pid == -1)
-     {
-        ty->hand_fd = NULL;
-        return ECORE_CALLBACK_CANCEL;
-     }
-#endif
+   int len, reads;
 
    // read up to 64 * 4096 bytes
    for (reads = 0; reads < 64; reads++)
      {
+        Eina_Unicode codepoint[4097];
+        char buf[4097];
         char *rbuf = buf;
+        int i, j;
         len = sizeof(buf) - 1;
 
         for (i = 0; i < (int)sizeof(ty->oldbuf) && ty->oldbuf[i] & 0x80; i++)
@@ -268,7 +246,7 @@ _fd_read_do(Termpty *ty, Ecore_Fd_Handler *fd_handler, Eina_Bool false_on_empty)
           }
         errno = 0;
         len = read(ty->fd, rbuf, len);
-        if ((len < 0 && errno != EAGAIN) ||
+        if ((len < 0 && !(errno == EAGAIN || errno == EINTR)) ||
             (len == 0 && errno != 0))
           {
              /* Do not print error if the child has exited */
@@ -278,7 +256,8 @@ _fd_read_do(Termpty *ty, Ecore_Fd_Handler *fd_handler, Eina_Bool false_on_empty)
                }
              close(ty->fd);
              ty->fd = -1;
-             if (ty->hand_fd) ecore_main_fd_handler_del(ty->hand_fd);
+             if (ty->hand_fd)
+               ecore_main_fd_handler_del(ty->hand_fd);
              ty->hand_fd = NULL;
              return ECORE_CALLBACK_CANCEL;
           }
@@ -314,6 +293,8 @@ _fd_read_do(Termpty *ty, Ecore_Fd_Handler *fd_handler, Eina_Bool false_on_empty)
                   if ((0xdc80 <= g) && (g <= 0xdcff) &&
                       (len - prev_i) <= (int)sizeof(ty->oldbuf))
                     {
+                       unsigned int k;
+
                        for (k = 0;
                             (k < (unsigned int)sizeof(ty->oldbuf)) &&
                             (k < (unsigned int)(len - prev_i));
@@ -337,16 +318,19 @@ _fd_read_do(Termpty *ty, Ecore_Fd_Handler *fd_handler, Eina_Bool false_on_empty)
 //        DBG("---------------- handle buf %i", j);
         termpty_handle_buf(ty, codepoint, j);
      }
-   if (ty->cb.change.func) ty->cb.change.func(ty->cb.change.data);
+   if (ty->cb.change.func)
+     ty->cb.change.func(ty->cb.change.data);
 #if defined(ENABLE_FUZZING) || defined(ENABLE_TESTS)
    if (len <= 0)
      {
         ty->exit_code = 0;
         ty->pid = -1;
 
-        if (ty->hand_exe_exit) ecore_event_handler_del(ty->hand_exe_exit);
+        if (ty->hand_exe_exit)
+          ecore_event_handler_del(ty->hand_exe_exit);
         ty->hand_exe_exit = NULL;
-        if (ty->hand_fd) ecore_main_fd_handler_del(ty->hand_fd);
+        if (ty->hand_fd)
+          ecore_main_fd_handler_del(ty->hand_fd);
         ty->hand_fd = NULL;
         ty->fd = -1;
         ty->slavefd = -1;
@@ -355,14 +339,80 @@ _fd_read_do(Termpty *ty, Ecore_Fd_Handler *fd_handler, Eina_Bool false_on_empty)
         return ECORE_CALLBACK_CANCEL;
      }
 #endif
-   if ((false_on_empty) && (len <= 0)) return ECORE_CALLBACK_CANCEL;
-   return EINA_TRUE;
+   if ((false_on_empty) && (len <= 0))
+     return ECORE_CALLBACK_CANCEL;
+
+   return ECORE_CALLBACK_RENEW;
 }
 
 static Eina_Bool
-_cb_fd_read(void *data, Ecore_Fd_Handler *fd_handler)
+_handle_write(Termpty *ty)
 {
-   return _fd_read_do(data, fd_handler, EINA_FALSE);
+   struct ty_sb *sb = &ty->write_buffer;
+   ssize_t len;
+
+   if (!sb->len)
+     return ECORE_CALLBACK_RENEW;
+
+   len = write(ty->fd, sb->buf, sb->len);
+   if (len < 0 && (errno != EINTR && errno != EAGAIN))
+     {
+        ERR(_("Could not write to file descriptor %d: %s"),
+            ty->fd, strerror(errno));
+        return ECORE_CALLBACK_CANCEL;
+     }
+   ty_sb_lskip(sb, len);
+
+   if (!sb->len && ty->hand_fd)
+     ecore_main_fd_handler_active_set(ty->hand_fd,
+                                      ECORE_FD_ERROR |
+                                      ECORE_FD_READ);
+
+   return ECORE_CALLBACK_RENEW;
+}
+
+static Eina_Bool
+_fd_do(Termpty *ty, Ecore_Fd_Handler *fd_handler, Eina_Bool false_on_empty)
+{
+   if (ecore_main_fd_handler_active_get(fd_handler, ECORE_FD_ERROR))
+     {
+        DBG("error while doing I/O on tty slave fd");
+        ty->hand_fd = NULL;
+        return ECORE_CALLBACK_CANCEL;
+     }
+   if (ty->fd == -1)
+     {
+        ty->hand_fd = NULL;
+        return ECORE_CALLBACK_CANCEL;
+     }
+
+   // it seems the BSDs can not read from this side of the pair if the other side
+   // is closed ... but no longer just bsd's - i have seen this now on linux
+   if (ty->pid == -1)
+     {
+        ty->hand_fd = NULL;
+        return ECORE_CALLBACK_CANCEL;
+     }
+
+   if (ecore_main_fd_handler_active_get(fd_handler, ECORE_FD_READ))
+     {
+        if (!_handle_read(ty, false_on_empty))
+          return ECORE_CALLBACK_CANCEL;
+     }
+
+   if (ecore_main_fd_handler_active_get(fd_handler, ECORE_FD_WRITE))
+     {
+        if (!_handle_write(ty))
+          return ECORE_CALLBACK_CANCEL;
+     }
+
+   return ECORE_CALLBACK_PASS_ON;
+}
+
+static Eina_Bool
+_cb_fd(void *data, Ecore_Fd_Handler *fd_handler)
+{
+   return _fd_do(data, fd_handler, EINA_FALSE);
 }
 
 static Eina_Bool
@@ -386,17 +436,21 @@ _cb_exe_exit(void *data,
    res = ECORE_CALLBACK_PASS_ON;
    while (ty->hand_fd && res != ECORE_CALLBACK_CANCEL)
      {
-        res = _fd_read_do(ty, ty->hand_fd, EINA_TRUE);
+        res = _fd_do(ty, ty->hand_fd, EINA_TRUE);
      }
 
-   if (ty->hand_fd) ecore_main_fd_handler_del(ty->hand_fd);
+   if (ty->hand_fd)
+     ecore_main_fd_handler_del(ty->hand_fd);
    ty->hand_fd = NULL;
-   if (ty->fd >= 0) close(ty->fd);
+   if (ty->fd >= 0)
+     close(ty->fd);
    ty->fd = -1;
-   if (ty->slavefd >= 0) close(ty->slavefd);
+   if (ty->slavefd >= 0)
+     close(ty->slavefd);
    ty->slavefd = -1;
 
-   if (ty->cb.exited.func) ty->cb.exited.func(ty->cb.exited.data);
+   if (ty->cb.exited.func)
+     ty->cb.exited.func(ty->cb.exited.data);
 
    return ECORE_CALLBACK_PASS_ON;
 }
@@ -422,7 +476,7 @@ termpty_resize_tabs(Termpty *ty, int old_w, int new_w)
 {
     unsigned int *new_tabs;
     int i;
-    size_t nb_elems, n;
+    size_t nb_elems;
 
     if ((new_w == old_w) && ty->tabs) return;
 
@@ -432,7 +486,7 @@ termpty_resize_tabs(Termpty *ty, int old_w, int new_w)
 
     if (ty->tabs)
       {
-         n = old_w;
+         size_t n = old_w;
          if (nb_elems < n) n = nb_elems;
          if (n > 0) memcpy(new_tabs, ty->tabs, n * sizeof(unsigned int));
          free(ty->tabs);
@@ -479,8 +533,8 @@ _is_shell_valid(const char *cmd)
 
 Termpty *
 termpty_new(const char *cmd, Eina_Bool login_shell, const char *cd,
-            int w, int h, Config *config, const char *emotion_mod,
-            const char *title, Ecore_Window window_id)
+            int w, int h, Config *config, const char *title,
+            Ecore_Window window_id)
 {
    Termpty *ty;
    const char *pty;
@@ -533,7 +587,7 @@ termpty_new(const char *cmd, Eina_Bool login_shell, const char *cd,
    ty->fd = STDIN_FILENO;
    ty->hand_fd = ecore_main_fd_handler_add(ty->fd,
                                            ECORE_FD_READ | ECORE_FD_ERROR,
-                                           _cb_fd_read, ty,
+                                           _cb_fd, ty,
                                            NULL, NULL);
    _pty_size(ty);
    termpty_save_register(ty);
@@ -655,12 +709,9 @@ termpty_new(const char *cmd, Eina_Bool login_shell, const char *cd,
      }
    if (!ty->pid)
      {
-        char buf[256];
-        int ret;
-
         if (cd)
           {
-             ret = chdir(cd);
+             int ret = chdir(cd);
              if (ret != 0)
                {
                   ERR(_("Could not change current directory to '%s': %s"),
@@ -718,22 +769,24 @@ termpty_new(const char *cmd, Eina_Bool login_shell, const char *cd,
              putenv("TERM=xterm");
           }
         putenv("XTERM_256_COLORS=1");
-        if (emotion_mod)
-          {
-             snprintf(buf, sizeof(buf), "EMOTION_ENGINE=%s", emotion_mod);
-             putenv(buf);
-          }
+        putenv("TERM_PROGRAM=terminology");
+        putenv("TERM_PROGRAM_VERSION=" PACKAGE_VERSION);
         if (window_id)
           {
+             char buf[256];
+
              snprintf(buf, sizeof(buf), "WINDOWID=%lu", window_id);
              putenv(buf);
           }
+#if ((EFL_VERSION_MAJOR > 1) || (EFL_VERSION_MINOR >= 24)) || ((EFL_VERSION_MAJOR == 1) && (EFL_VERSION_MINOR == 23) && (EFL_VERSION_MICRO == 99))
+        eina_file_close_from(3, NULL);
+#endif
         if (!login_shell)
           execvp(args[0], (char *const *)args);
         else
           {
              char *cmdfile, *cmd0;
-             
+
              cmdfile = (char *)args[0];
              cmd0 = alloca(strlen(cmdfile) + 2);
              cmd0[0] = '-';
@@ -747,10 +800,10 @@ termpty_new(const char *cmd, Eina_Bool login_shell, const char *cd,
    ty->slavefd = -1;
 
    ty->hand_fd = ecore_main_fd_handler_add(ty->fd, ECORE_FD_READ,
-                                           _cb_fd_read, ty,
+                                           _cb_fd, ty,
                                            NULL, NULL);
    /* ensure we're not missing a read */
-   _cb_fd_read(ty, ty->hand_fd);
+   _cb_fd(ty, ty->hand_fd);
 
    _pty_size(ty);
    termpty_save_register(ty);
@@ -816,19 +869,14 @@ termpty_free(Termpty *ty)
              ty->pid = -1;
           }
      }
-   if (ty->hand_exe_exit) ecore_event_handler_del(ty->hand_exe_exit);
-   if (ty->hand_fd) ecore_main_fd_handler_del(ty->hand_fd);
-   if (ty->prop.title) eina_stringshare_del(ty->prop.title);
-   if (ty->prop.user_title) eina_stringshare_del(ty->prop.user_title);
-   if (ty->prop.icon) eina_stringshare_del(ty->prop.icon);
-   if (ty->back)
-     {
-        size_t i;
-
-        for (i = 0; i < ty->backsize; i++)
-          termpty_save_free(ty, &ty->back[i]);
-        free(ty->back);
-     }
+   if (ty->hand_exe_exit)
+     ecore_event_handler_del(ty->hand_exe_exit);
+   if (ty->hand_fd)
+     ecore_main_fd_handler_del(ty->hand_fd);
+   eina_stringshare_del(ty->prop.title);
+   eina_stringshare_del(ty->prop.user_title);
+   eina_stringshare_del(ty->prop.icon);
+   termpty_backlog_free(ty);
    free(ty->screen);
    free(ty->screen2);
    if (ty->hl.links)
@@ -846,6 +894,7 @@ termpty_free(Termpty *ty)
    free(ty->hl.bitmap);
    free(ty->buf);
    free(ty->tabs);
+   ty_sb_free(&ty->write_buffer);
    free(ty);
 }
 
@@ -885,7 +934,7 @@ _termpty_line_is_empty(const Termcell *cells, ssize_t nb_cells)
 ssize_t
 termpty_line_length(const Termcell *cells, ssize_t nb_cells)
 {
-   ssize_t len = nb_cells;
+   ssize_t len;
 
    if (!cells)
      return 0;
@@ -901,83 +950,6 @@ termpty_line_length(const Termcell *cells, ssize_t nb_cells)
    return 0;
 }
 
-#define BACKLOG_ROW_GET(Ty, Y) \
-   (&Ty->back[(Ty->backsize + ty->backpos - ((Y) - 1 )) % Ty->backsize])
-
-
-static inline void
-verify_beacon(const Termpty *ty EINA_UNUSED, int verbose EINA_UNUSED)
-{
-#if 0
-   Termsave *ts;
-   int nb_lines;
-   int backlog_y = ty->backlog_beacon.backlog_y;
-   int screen_y = ty->backlog_beacon.screen_y;
-
-   assert(ty->backlog_beacon.screen_y >= 0);
-   assert(ty->backlog_beacon.backlog_y >= 0);
-   assert(ty->backlog_beacon.screen_y >= ty->backlog_beacon.backlog_y);
-
-   if (verbose)
-     {
-        ERR("FROM screen_y:%d backlog_y:%d",
-            screen_y, backlog_y);
-     }
-   while (backlog_y > 0)
-     {
-        ts = BACKLOG_ROW_GET(ty, backlog_y);
-        if (!ts->cells)
-          {
-             if (verbose)
-               {
-                  ERR("went too far: screen_y:%d backlog_y:%d",
-                      screen_y, backlog_y);
-               }
-             return;
-          }
-
-        nb_lines = (ts->w == 0) ? 1 : (ts->w + ty->w - 1) / ty->w;
-        screen_y -= nb_lines;
-        backlog_y--;
-        if (verbose)
-          {
-             ERR("nb_lines:%d screen_y:%d backlog_y:%d ts->w:%d ty->w:%d",
-                 nb_lines, screen_y, backlog_y, ts->w, ty->w);
-          }
-        assert(screen_y >= backlog_y);
-
-     }
-   if (verbose)
-     {
-        ERR("TO screen_y:%d backlog_y:%d",
-            screen_y, backlog_y);
-     }
-   assert (backlog_y == 0);
-   assert (screen_y == 0);
-#endif
-}
-
-static void
-_backlog_remove_latest_nolock(Termpty *ty)
-{
-   Termsave *ts;
-   if (ty->backsize == 0)
-     return;
-   ts = BACKLOG_ROW_GET(ty, 1);
-
-   if (ty->backpos == 0)
-     ty->backpos = ty->backsize - 1;
-   else
-     ty->backpos--;
-
-   /* reset beacon */
-   ty->backlog_beacon.screen_y = 0;
-   ty->backlog_beacon.backlog_y = 0;
-   verify_beacon(ty, 0);
-
-   termpty_save_free(ty, ts);
-}
-
 
 void
 termpty_text_save_top(Termpty *ty, Termcell *cells, ssize_t w_max)
@@ -989,7 +961,6 @@ termpty_text_save_top(Termpty *ty, Termcell *cells, ssize_t w_max)
      return;
    assert(ty->back);
 
-   verify_beacon(ty, 0);
    termpty_backlog_lock();
 
    w = termpty_line_length(cells, w_max);
@@ -1009,7 +980,6 @@ termpty_text_save_top(Termpty *ty, Termcell *cells, ssize_t w_max)
              termpty_save_expand(ty, ts, cells, w);
              ty->backlog_beacon.screen_y += (ts->w + ty->w - 1) / ty->w
                                           - (old_len + ty->w - 1) / ty->w;
-             verify_beacon(ty, 0);
              return;
           }
      }
@@ -1032,7 +1002,6 @@ add_new_ts:
         ty->backlog_beacon.screen_y = 0;
         ty->backlog_beacon.backlog_y = 0;
      }
-   verify_beacon(ty, 0);
 }
 
 
@@ -1049,42 +1018,12 @@ termpty_row_length(Termpty *ty, int y)
    return wret;
 }
 
-ssize_t
-termpty_backlog_length(Termpty *ty)
-{
-   int backlog_y = ty->backlog_beacon.backlog_y;
-   int screen_y = ty->backlog_beacon.screen_y;
-
-   if (!ty->backsize)
-     return 0;
-   verify_beacon(ty, 0);
-
-   for (backlog_y++; backlog_y < (int)ty->backsize; backlog_y++)
-     {
-        int nb_lines;
-        const Termsave *ts;
-
-        ts = BACKLOG_ROW_GET(ty, backlog_y);
-        if (!ts->cells)
-          goto end;
-
-        nb_lines = (ts->w == 0) ? 1 : (ts->w + ty->w - 1) / ty->w;
-        screen_y += nb_lines;
-        ty->backlog_beacon.screen_y = screen_y;
-        ty->backlog_beacon.backlog_y = backlog_y;
-        verify_beacon(ty, 0);
-     }
-end:
-     return ty->backlog_beacon.screen_y;
-}
-
 void
 termpty_backscroll_adjust(Termpty *ty, int *scroll)
 {
    int backlog_y = ty->backlog_beacon.backlog_y;
    int screen_y = ty->backlog_beacon.screen_y;
 
-   verify_beacon(ty, 0);
    if ((ty->backsize == 0) || (*scroll <= 0))
      {
         *scroll = 0;
@@ -1092,7 +1031,6 @@ termpty_backscroll_adjust(Termpty *ty, int *scroll)
      }
    if (*scroll < screen_y)
      {
-        verify_beacon(ty, 0);
         return;
      }
 
@@ -1106,18 +1044,15 @@ termpty_backscroll_adjust(Termpty *ty, int *scroll)
         if (!ts->cells || backlog_y >= (int)ty->backsize)
           {
              *scroll = ty->backlog_beacon.screen_y;
-             verify_beacon(ty, 0);
              return;
           }
         nb_lines = (ts->w == 0) ? 1 : (ts->w + ty->w - 1) / ty->w;
         screen_y += nb_lines;
         ty->backlog_beacon.screen_y = screen_y;
         ty->backlog_beacon.backlog_y = backlog_y;
-        verify_beacon(ty, 0);
         backlog_y++;
         if (*scroll <= screen_y)
           {
-             verify_beacon(ty, 0);
              return;
           }
      }
@@ -1141,7 +1076,6 @@ _termpty_cellrow_from_beacon_get(Termpty *ty, int requested_y, ssize_t *wret)
         ty->backlog_beacon.backlog_y = 0;
         ty->backlog_beacon.screen_y = 0;
      }
-   verify_beacon(ty, 0);
 
    /* going upward */
    while (requested_y >= screen_y)
@@ -1160,7 +1094,6 @@ _termpty_cellrow_from_beacon_get(Termpty *ty, int requested_y, ssize_t *wret)
              screen_y += nb_lines;
              ty->backlog_beacon.screen_y = screen_y;
              ty->backlog_beacon.backlog_y = backlog_y;
-             verify_beacon(ty, 0);
           }
 
         if ((screen_y - nb_lines < requested_y) && (requested_y <= screen_y))
@@ -1187,7 +1120,6 @@ _termpty_cellrow_from_beacon_get(Termpty *ty, int requested_y, ssize_t *wret)
 
         ty->backlog_beacon.screen_y = screen_y;
         ty->backlog_beacon.backlog_y = backlog_y;
-        verify_beacon(ty, 0);
 
         if ((screen_y - nb_lines < requested_y) && (requested_y <= screen_y))
           {
@@ -1251,18 +1183,22 @@ termpty_cell_get(Termpty *ty, int y_requested, int x_requested)
 void
 termpty_write(Termpty *ty, const char *input, int len)
 {
-#if defined(ENABLE_TESTS)
-   ty_sb_add(&ty->write_buffer, input, len);
-#else
-   int fd = ty->fd;
 #if defined(ENABLE_FUZZING)
-   fd = ty->fd_dev_null;
-#endif
-   if (fd < 0) return;
-   if (write(fd, input, len) < 0)
-     ERR(_("Could not write to file descriptor %d: %s"),
-         fd, strerror(errno));
+   return;
 #endif
+   int res = ty_sb_add(&ty->write_buffer, input, len);
+
+   if (res < 0)
+     {
+        ERR("failure to add %d characters to write buffer", len);
+     }
+   else if (ty->hand_fd)
+     {
+        ecore_main_fd_handler_active_set(ty->hand_fd,
+                                         ECORE_FD_ERROR |
+                                         ECORE_FD_READ |
+                                         ECORE_FD_WRITE);
+     }
 }
 
 struct screen_info
@@ -1365,6 +1301,26 @@ _termpty_line_rewrap(Termpty *ty, Termcell *src_cells, int len,
      }
 }
 
+static void
+_backlog_remove_latest_nolock(Termpty *ty)
+{
+   Termsave *ts;
+   if (ty->backsize == 0)
+     return;
+   ts = BACKLOG_ROW_GET(ty, 1);
+
+   if (ty->backpos == 0)
+     ty->backpos = ty->backsize - 1;
+   else
+     ty->backpos--;
+
+   /* reset beacon */
+   ty->backlog_beacon.screen_y = 0;
+   ty->backlog_beacon.backlog_y = 0;
+
+   termpty_save_free(ty, ts);
+}
+
 void
 termpty_resize(Termpty *ty, int new_w, int new_h)
 {
@@ -1482,7 +1438,6 @@ termpty_resize(Termpty *ty, int new_w, int new_h)
    ty->backlog_beacon.backlog_y = 0;
    ty->backlog_beacon.screen_y = 0;
 
-   verify_beacon(ty, 0);
    return;
 
 bad:
@@ -1490,32 +1445,6 @@ bad:
    free(new_screen);
 }
 
-void
-termpty_backlog_size_set(Termpty *ty, size_t size)
-{
-   if (ty->backsize == size)
-     return;
-
-   /* TODO: RESIZE: handle that case better: changing backscroll size */
-   termpty_backlog_lock();
-
-   if (ty->back)
-     {
-        size_t i;
-
-        for (i = 0; i < ty->backsize; i++)
-          termpty_save_free(ty, &ty->back[i]);
-        free(ty->back);
-     }
-   if (size > 0)
-     ty->back = calloc(1, sizeof(Termsave) * size);
-   else
-     ty->back = NULL;
-   ty->backpos = 0;
-   ty->backsize = size;
-   termpty_backlog_unlock();
-}
-
 pid_t
 termpty_pid_get(const Termpty *ty)
 {
@@ -1526,11 +1455,17 @@ void
 termpty_block_free(Termblock *tb)
 {
    char *s;
-   if (tb->path) eina_stringshare_del(tb->path);
-   if (tb->link) eina_stringshare_del(tb->link);
-   if (tb->chid) eina_stringshare_del(tb->chid);
-   if (tb->obj) evas_object_del(tb->obj);
-   EINA_LIST_FREE(tb->cmds, s) free(s);
+
+   if (!tb)
+     return;
+
+   eina_stringshare_del(tb->path);
+   eina_stringshare_del(tb->link);
+   eina_stringshare_del(tb->chid);
+   if (tb->obj)
+     evas_object_del(tb->obj);
+   EINA_LIST_FREE(tb->cmds, s)
+      free(s);
    free(tb);
 }
 
