@@ -13,6 +13,7 @@ typedef struct _Termblock     Termblock;
 typedef struct _Termexp       Termexp;
 typedef struct _Termpty       Termpty;
 typedef struct _Termlink      Term_Link;
+typedef struct _TitleIconElem TitleIconElem;
 
 #define COL_DEF        0
 #define COL_BLACK      1
@@ -168,12 +169,7 @@ struct _Termpty
    Backlog_Beacon backlog_beacon;
    int w, h;
    int fd, slavefd;
-#if defined(ENABLE_TESTS)
    struct ty_sb write_buffer;
-#endif
-#if defined(ENABLE_FUZZING)
-   int fd_dev_null;
-#endif
    struct {
       int curid;
       Eina_Hash *blocks;
@@ -212,6 +208,7 @@ struct _Termpty
        uint8_t *bitmap;
        uint32_t size;
    } hl;
+   TitleIconElem *title_icon_stack;
 };
 
 struct _Termcell
@@ -276,22 +273,17 @@ void       termpty_init(void);
 void       termpty_shutdown(void);
 
 Termpty   *termpty_new(const char *cmd, Eina_Bool login_shell, const char *cd,
-                       int w, int h, Config *config, const char *emotion_mod,
-                       const char *title, Ecore_Window window_id);
+                       int w, int h, Config *config, const char *title,
+                       Ecore_Window window_id);
 void       termpty_free(Termpty *ty);
 void       termpty_config_update(Termpty *ty, Config *config);
 
-void       termpty_backlog_lock(void);
-void       termpty_backlog_unlock(void);
-
 Termcell  *termpty_cellrow_get(Termpty *ty, int y, ssize_t *wret);
 Termcell * termpty_cell_get(Termpty *ty, int y_requested, int x_requested);
 ssize_t termpty_row_length(Termpty *ty, int y);
 void       termpty_write(Termpty *ty, const char *input, int len);
 void       termpty_resize(Termpty *ty, int new_w, int new_h);
 void       termpty_resize_tabs(Termpty *ty, int old_w, int new_w);
-void       termpty_backlog_size_set(Termpty *ty, size_t size);
-ssize_t    termpty_backlog_length(Termpty *ty);
 void       termpty_backscroll_adjust(Termpty *ty, int *scroll);
 
 pid_t      termpty_pid_get(const Termpty *ty);
