@@ -217,6 +217,19 @@ termio_take_selection(Evas_Object *obj,
    return EINA_FALSE;
 }
 
+void
+termio_remove_links(Termio *sd)
+{
+   sd->link.string = NULL;
+   sd->link.x1 = -1;
+   sd->link.y1 = -1;
+   sd->link.x2 = -1;
+   sd->link.y2 = -1;
+   sd->link.suspend = EINA_FALSE;
+   sd->link.id = 0;
+   sd->link.objs = 0;
+}
+
 #ifndef TYTEST
 void
 termio_set_cursor_shape(Evas_Object *obj EINA_UNUSED,
@@ -263,10 +276,6 @@ _termpty_init(Termpty *ty, Config *config)
    assert(ty->screen2);
    ty->circular_offset = 0;
    ty->fd = STDIN_FILENO;
-#if defined(ENABLE_FUZZING)
-   ty->fd_dev_null = open("/dev/null", O_WRONLY|O_APPEND);
-   assert(ty->fd_dev_null >= 0);
-#endif
    ty->hl.bitmap = calloc(1, HL_LINKS_MAX / 8); /* bit map for 1 << 16 elements */
    assert(ty->hl.bitmap);
    /* Mark id 0 as set */
@@ -275,24 +284,9 @@ _termpty_init(Termpty *ty, Config *config)
    ty->backlog_beacon.screen_y = 0;
 }
 
-static void
-_termpty_shutdown(Termpty *ty)
-{
-#if defined(ENABLE_TESTS)
-   ty_sb_free(&ty->write_buffer);
-#endif
-#if defined(ENABLE_FUZZING)
-   close(ty->fd_dev_null);
-#endif
-}
-
 int
 main(int argc EINA_UNUSED, char **argv EINA_UNUSED)
 {
-   char buf[4097];
-   Eina_Unicode codepoint[4097];
-   int len, i, j, k;
-
    eina_init();
 
 #ifdef TYTEST
@@ -321,8 +315,11 @@ main(int argc EINA_UNUSED, char **argv EINA_UNUSED)
 
    do
      {
+        char buf[4097];
+        Eina_Unicode codepoint[4097];
+        int i, j;
         char *rbuf = buf;
-        len = sizeof(buf) - 1;
+        int len = sizeof(buf) - 1;
 
         for (i = 0; i < (int)sizeof(_ty.oldbuf) && _ty.oldbuf[i] & 0x80; i++)
           {
@@ -356,6 +353,7 @@ main(int argc EINA_UNUSED, char **argv EINA_UNUSED)
                   if ((0xdc80 <= g) && (g <= 0xdcff) &&
                       (len - prev_i) <= (int)sizeof(_ty.oldbuf))
                     {
+                       int k;
                        for (k = 0;
                             (k < (int)sizeof(_ty.oldbuf)) &&
                             (k < (len - prev_i));
@@ -384,8 +382,6 @@ main(int argc EINA_UNUSED, char **argv EINA_UNUSED)
    _tytest_checksum(&_ty);
 #endif
 
-   _termpty_shutdown(&_ty);
-
 #ifdef TYTEST
    tytest_shutdown();
 #endif
