@@ -2,7 +2,7 @@
 #define _TYTEST_H__ 1
 
 #if defined(ENABLE_TESTS)
-#define evas_object_textgrid_palette_get test_textgrid_palette_get
+#define evas_object_textgrid_palette_get  test_textgrid_palette_get
 void
 test_textgrid_palette_get(const Evas_Object *obj,
                           Evas_Textgrid_Palette pal,
@@ -12,14 +12,24 @@ test_textgrid_palette_get(const Evas_Object *obj,
                           int *b,
                           int *a);
 
-#define evas_object_textgrid_cellrow_get test_textgrid_cellrow_get
+#define evas_object_textgrid_cellrow_get  test_textgrid_cellrow_get
 Evas_Textgrid_Cell *
 test_textgrid_cellrow_get(Evas_Object *obj, int y);
+
+
 void
 tytest_termio_resize(int w, int h);
 
 void tytest_init(void);
 void tytest_shutdown(void);
+#endif
+
+#if defined(ENABLE_TESTS) || defined(ENABLE_TEST_UI)
+void
+test_pointer_canvas_xy_get(int *mx,
+                           int *my);
+
+void test_set_mouse_pointer(int mx, int my);
+#endif
 
 #endif
-#endif
